@@ -6,7 +6,7 @@
  *
  * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2015, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -227,6 +227,7 @@ namespace tr1
 
 #undef IUTEST_HAS_EXCEPTIONS
 #undef IUTEST_HAS_RTTI
+#undef IUTEST_HAS_REGEX
 #undef IUTEST_HAS_SEH
 
 #undef IUTEST_HAS_STREAMCAPTURE
@@ -275,6 +276,7 @@ namespace tr1
 
 #define IUTEST_HAS_EXCEPTIONS		GTEST_HAS_EXCEPTIONS
 #define IUTEST_HAS_RTTI				GTEST_HAS_RTTI
+#define IUTEST_HAS_REGEX			GTEST_USES_POSIX_RE
 #define IUTEST_HAS_SEH				GTEST_HAS_SEH
 
 #include "switch/iutest_switch_port.hpp"
@@ -320,6 +322,15 @@ namespace tr1
 #define IUTEST_OPERAND(op)			op
 #define IUTEST_EXPRESSION(expr)		expr
 
+#if GTEST_VER < 0x01070000
+
+#undef GTEST_COMPILE_ASSERT_
+#define GTEST_COMPILE_ASSERT_(expr, msg) \
+  typedef ::testing::internal::CompileAssert<(static_cast<bool>(expr))> \
+      msg[static_cast<bool>(expr) ? 1 : -1] GTEST_ATTRIBUTE_UNUSED_
+
+#endif
+
 namespace testing
 {
 
