@@ -6,7 +6,7 @@
  *
  * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2015, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -39,8 +39,11 @@
 #  if defined(_WIN32_WCE)
 #    define IUTEST_OS_WINDOWS_MOBILE	1
 #    define IUTEST_PLATFORM				"Windows CE"
-#  elif defined(__MINGW__) || defined(__MINGW32__)
+#  elif defined(__MINGW__) || defined(__MINGW32__) || defined(__MINGW64__)
 #    define IUTEST_OS_WINDOWS_MINGW		1
+#  elif defined(__WINE__)
+#    define IUTEST_OS_WINDOWS_WINE		1
+#    define IUTEST_PLATFORM				"WINE"
 #  elif defined(__CUDACC__)
 #    define IUTEST_OS_WINDOWS_CUDA		1
 #  elif defined(WINAPI_FAMILY)
@@ -63,16 +66,14 @@
 #  include "TargetConditionals.h"
 #  if TARGET_OS_IPHONE
 #    define IUTEST_OS_IOS				1
-#    if TARGET_IPHONE_SIMULATOR
-#      define IUTEST_OS_IOS_SIMULATOR	1
-#      define IUTEST_PLATFORM			"iOS Simulator"
-#    else
-#      define IUTEST_PLATFORM			"iOS"
-#    endif
+#    define IUTEST_PLATFORM				"iOS"
 #  else
 #    define IUTEST_OS_MAC				1
 #    define IUTEST_PLATFORM				"Mac OS"
 #  endif
+#elif defined(__FreeBSD__)
+#  define IUTEST_OS_FREEBSD				1
+#  define IUTEST_PLATFORM				"FreeBSD"
 #elif defined(sun) || defined(__sun)
 #  define IUTEST_OS_SOLARIS				1
 #  define IUTEST_PLATFORM				"Solaris"
@@ -564,8 +565,8 @@
 #      define IUTEST_HAS_NOEXCEPT	1
 #    endif
 #  elif defined(_MSC_VER)
-#    if _MSC_FULL_VER >= 190022310
-//#      define IUTEST_HAS_NOEXCEPT	1 // https://connect.microsoft.com/VisualStudio/feedback/details/809079/torino-compile-error-template-noexcept
+#    if _MSC_FULL_VER >= 190022816
+#      define IUTEST_HAS_NOEXCEPT	1 // https://connect.microsoft.com/VisualStudio/feedback/details/809079/torino-compile-error-template-noexcept
 #    endif
 #  elif defined(__INTEL_COMPILER)
 #    if __INTEL_COMPILER >= 1400
@@ -655,6 +656,21 @@
 #  define IUTEST_HAS_STRONG_ENUMS		0
 #endif
 
+//! quick_exit
+#if !defined(IUTEST_HAS_QUICK_EXIT)
+#  if   (defined(_GLIBCXX_HAVE_QUICK_EXIT) && defined(_GLIBCXX_HAVE_AT_QUICK_EXIT)) || defined(_LIBCPP_HAS_QUICK_EXIT)
+#    define IUTEST_HAS_QUICK_EXIT	1
+#  elif defined(_MSC_VER)
+#    if _MSC_VER > 1800
+#      define IUTEST_HAS_QUICK_EXIT	1
+#    endif
+#  endif
+#endif
+
+#if !defined(IUTEST_HAS_QUICK_EXIT)
+#  define IUTEST_HAS_QUICK_EXIT		0
+#endif
+
 // c++
 //! has exceptions
 #if !defined(IUTEST_HAS_EXCEPTIONS)
@@ -664,7 +680,7 @@
 #    endif
 #    define IUTEST_HAS_EXCEPTIONS	_HAS_EXCEPTIONS
 #  elif defined(__clang__)
-#    if __has_feature(cxx_exceptions)
+#    if __EXCEPTIONS && __has_feature(cxx_exceptions)
 #      define IUTEST_HAS_EXCEPTIONS	1
 #    endif
 #  elif defined(__GNUC__)
@@ -918,24 +934,58 @@
 #if !defined(IUTEST_HAS_ANALYSIS_ASSUME)
 #  if defined(_MSC_VER) && (_MSC_VER >= 1500) && !defined(__CUDACC__)
 #    define IUTEST_HAS_ANALYSIS_ASSUME		1
+#    define IUTEST_ANALYSIS_ASSUME			__analysis_assume
+#  elif defined(__clang__)
+#    if __has_builtin(__builtin_assume)
+#      define IUTEST_HAS_ANALYSIS_ASSUME	1
+#      define IUTEST_ANALYSIS_ASSUME		__builtin_assume
+#    endif
 #  endif
 #endif
 
 #if !defined(IUTEST_HAS_ANALYSIS_ASSUME)
 #  define IUTEST_HAS_ANALYSIS_ASSUME		0
 #endif
+#if !defined(IUTEST_ANALYSIS_ASSUME)
+#  define IUTEST_ANALYSIS_ASSUME(...)		(void)0
+#endif
+
+// C11
+
+//! has _Generic
+#if !defined(IUTEST_HAS_GENERIC)
+#  if   defined(__clang__)
+#    if __has_feature(c_generic_selections)
+#      define IUTEST_HAS_GENERIC	1
+#    endif
+#  elif defined(__GNUC__)
+//#    if (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 9))
+//#      define IUTEST_HAS_GENERIC	1
+//#    endif
+#  endif
+#endif
+
+#if !defined(IUTEST_HAS_GENERIC)
+#  define IUTEST_HAS_GENERIC		0
+#endif
 
 // attribute
 
 //! unused attribute
 #if !defined(IUTEST_ATTRIBUTE_UNUSED_)
-#  if (defined(__GNUC__) && !defined(COMPILER_ICC)) || defined(__clang__)
+#  if (defined(__GNUC__) && !defined(COMPILER_ICC))
 #    define IUTEST_ATTRIBUTE_UNUSED_	__attribute__ ((unused))
-#  else
-#    define IUTEST_ATTRIBUTE_UNUSED_
+#  elif defined(__clang__)
+#    if __has_attribute(unused)
+#      define IUTEST_ATTRIBUTE_UNUSED_	__attribute__ ((unused))
+#    endif
 #  endif
 #endif
 
+#if !defined(IUTEST_ATTRIBUTE_UNUSED_)
+#  define IUTEST_ATTRIBUTE_UNUSED_
+#endif
+
 //! pure attribute
 #if !defined(IUTEST_ATTRIBUTE_PURE_)
 #  if defined(__GNUC__) && !defined(COMPILER_ICC)
