@@ -6,7 +6,7 @@
  *
  * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2015, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -63,12 +63,18 @@
 
 #define IUTEST_PP_COUNTOF(x)		(sizeof(x)/sizeof(x[0]))
 
-#if !defined(IUTEST_HAS_COUNTER_MACRO)
+#if IUTEST_HAS_COUNTER_MACRO
 #  define IUTEST_PP_COUNTER			__COUNTER__
 #else
 #  define IUTEST_PP_COUNTER			__LINE__
 #endif
 
+#if IUTEST_HAS_COUNTER_MACRO
+#  define IUTEST_PP_UNIQUEID		IUTEST_PP_CAT(__LINE__, __COUNTER__)
+#else
+#  define IUTEST_PP_UNIQUEID		__LINE__
+#endif
+
 #define IUTEST_UNUSED_VAR(x)		(void)(x)
 
 // DEC
@@ -282,6 +288,8 @@
 #define IUTEST_PP_INC_100	nil
 
 // REPEAT
+#define IUTEST_PP_LIMIT_REPEAT	50
+
 #define IUTEST_PP_REPEAT_PARAMS_MACRO_(i, param)	param
 #define IUTEST_PP_REPEAT_PARAMS_MACRO_IN_BINARY_(i, param1, param2)	param2(i, param1)
 
@@ -349,6 +357,8 @@
 #define IUTEST_PP_REPEAT_I_50(i, m, p1, p2)		m(i, p1, p2) IUTEST_PP_REPEAT_I_49(IUTEST_PP_INC(i), m, p1, p2)
 
 // ENUM
+#define IUTEST_PP_LIMIT_ENUM	50
+
 #define IUTEST_PP_ENUM_PARAMS_MACRO_(i, param)	IUTEST_PP_CAT(param, i)
 #define IUTEST_PP_ENUM_PARAMS_MACRO_IN_BINARY_(i, param1, param2)	param2(i, param1)
 
