@@ -6,7 +6,7 @@
  *
  * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2015, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -26,7 +26,6 @@ namespace iutest
 
 //======================================================================
 // declare
-class Test;
 template<typename T>class WithParamInterface;
 template<typename T>class TestWithParam;
 
@@ -43,7 +42,9 @@ public:
 	Test(void)
 		: test_info_(NULL)
 		, m_test_info(NULL)
+#if IUTEST_HAS_GENRAND
 		, m_random_seed(0)
+#endif
 	{
 		CurrentTestObserver::s_current = this;
 	}
@@ -182,6 +183,10 @@ private:
 	*/
 	static void RecordPropertyString(const ::std::string& key, const ::std::string& value);
 
+private:
+	struct should_be_SetUp {};
+	virtual should_be_SetUp* Setup(void) IUTEST_CXX_FINAL { return NULL; }
+
 private:
 	template<typename DMY>
 	class Observer
@@ -234,12 +239,21 @@ public:
 	static const ParamType& GetParam(void)
 	{
 		IUTEST_CHECK_(s_params != NULL) << "GetParam() can only use the value-parameterized test";
-#if IUTEST_HAS_ANALYSIS_ASSUME
-		__analysis_assume(s_params != NULL);
-#endif
+		IUTEST_ANALYSIS_ASSUME(s_params != NULL);
 		return *s_params;
 	}
 
+#if IUTEST_HAS_TUPLE
+	/**
+	 * @brief	パラメータの取得
+	*/
+	template<int N>
+	static const typename tuples::tuple_element<N, ParamType>::type& GetParam(void)
+	{
+		return tuples::get<N>(GetParam());
+	}
+#endif
+
 	/** @private */
 	static void SetParam(const ParamType* params) IUTEST_CXX_NOEXCEPT_SPEC { s_params = params; }
 
@@ -259,6 +273,46 @@ class TestWithParam : public Test, public WithParamInterface<T>
 {
 };
 
+namespace detail
+{
+
+#if !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION) && !defined(IUTEST_NO_FUNCTION_TEMPLATE_ORDERING)
+
+/**
+ * @brief	有益な TestFixture が定義されているかどうか
+*/
+template<typename T>
+class is_useful_testfixture : public iutest_type_traits::false_type {};
+
+namespace is_useful_testfixture_helper
+{
+
+template<typename T>
+class is_override_setup {
+	template<bool b, typename U>struct impl { typedef iutest_type_traits::false_type type; };
+	template<typename U>struct impl<true, U>
+	{
+		typedef int  yes_t;
+		typedef char no_t;
+		static no_t check(void(Test::*)());
+		static yes_t check(...);
+		typedef iutest_type_traits::bool_constant< sizeof(check(&U::SetUp)) == sizeof(yes_t) > type;
+	};
+public:
+	typedef typename impl< iutest_type_traits::is_base_of<Test, T>::value, T>::type type;
+};
+
+}
+
+template<typename T>
+class is_useful_testfixture<void (int(T))> : public is_useful_testfixture_helper::is_override_setup<T>::type
+{
+};
+
+#endif
+
+}
+
 }	// end of namespace iutest
 
 template<typename DMY>
