@@ -6,7 +6,7 @@
  *
  * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2015, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -61,6 +61,8 @@
 */
 #define IUTEST_PEEP_STATIC_GET(class_name, member_name)	(*::iutest::detail::peep_tag< IUTEST_PEEP_TAG_NAME_(class_name, member_name)<class_name> >::value)
 
+#if IUTEST_HAS_PEEP_CLASS
+
 /**
  * @brief	private メンバーへのアクセスクラス宣言
  * @param	class_name	= クラス名
@@ -68,6 +70,7 @@
 */
 #define IUTEST_PEEP(class_name, member_name)	::iutest::Peep< class_name, IUTEST_PEEP_TAG_NAME_(class_name, member_name)<class_name> >::type
 
+#endif
 
 /**
  * @private
@@ -75,7 +78,8 @@
 */
 #define IUTEST_MAKE_PEEP_TAG_(member_type, class_name, member_name)															\
 	template<typename T>struct IUTEST_PEEP_TAG_NAME_(class_name, member_name);												\
-	template<>struct IUTEST_PEEP_TAG_NAME_(class_name, member_name)<class_name> { typedef member_type type; };				\
+	template<>struct IUTEST_PEEP_TAG_NAME_(class_name, member_name)<class_name> {											\
+						 typedef ::iutest_type_traits::identity<member_type>::type type; };										\
 	template<typename T, typename Tag, typename Tag::type X>struct IUTEST_PEEP_SETTER_NAME_(class_name, member_name) {		\
 	IUTEST_PEEP_SETTER_NAME_(class_name, member_name)(void) { ::iutest::detail::peep_tag<Tag>::value = X; }					\
 	static IUTEST_PEEP_SETTER_NAME_(class_name, member_name) instance;														\
@@ -98,8 +102,9 @@ namespace iutest {
 // struct
 namespace detail
 {
+
 /**
-* @brief	private メンバー保持構造体
+ * @brief	private メンバー保持構造体
 */
 template<typename Tag>
 struct peep_tag
@@ -111,7 +116,7 @@ typename Tag::type peep_tag<Tag>::value;
 
 }	// end of namespace detail
 
-#if !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION)
+#if IUTEST_HAS_PEEP_CLASS
 
 /**
  * @brief	private	メンバーアクセスオブジェクト
