@@ -6,7 +6,7 @@
  *
  * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2015, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -215,6 +215,176 @@
 #  define	IUTEST_ASSUME_STRNOTIN(substr, actual)		IUTEST_TEST_STRNOTIN(substr, actual, IUTEST_ASSUME_FAILURE)
 #endif
 
+#if IUTEST_HAS_REGEX
+
+/**
+ * @ingroup	IUTEST_ASSERT_
+ * @brief	文字列正規表現一致 テスト
+ * @param	regex_str	= 正規表現文字列
+ * @param	actual		= 検査対象文字列
+*/
+#ifndef IUTEST_ASSERT_MATCHES_REGEXEQ
+#  define	IUTEST_ASSERT_MATCHES_REGEXEQ(regex_str, actual)		\
+	IUTEST_TEST_MATCHES_REGEXEQ(regex_str, actual, IUTEST_ASSERT_FAILURE)
+#endif
+/**
+ * @ingroup	IUTEST_EXPECT_
+ * @brief	文字列正規表現一致 テスト
+ * @param	regex_str	= 正規表現文字列
+ * @param	actual		= 検査対象文字列
+ */
+#ifndef IUTEST_EXPECT_MATCHES_REGEXEQ
+#  define	IUTEST_EXPECT_MATCHES_REGEXEQ(regex_str, actual)		\
+	IUTEST_TEST_MATCHES_REGEXEQ(regex_str, actual, IUTEST_EXPECT_FAILURE)
+#endif
+/**
+ * @ingroup	IUTEST_INFORM
+ * @brief	文字列正規表現一致 テスト
+ * @param	regex_str	= 正規表現文字列
+ * @param	actual		= 検査対象文字列
+ */
+#ifndef IUTEST_INFORM_MATCHES_REGEXEQ
+#  define	IUTEST_INFORM_MATCHES_REGEXEQ(regex_str, actual)		\
+	IUTEST_TEST_MATCHES_REGEXEQ(regex_str, actual, IUTEST_INFORM_FAILURE)
+#endif
+/**
+ * @ingroup	IUTEST_ASSUME
+ * @brief	文字列正規表現一致 テスト
+ * @param	regex_str	= 正規表現文字列
+ * @param	actual		= 検査対象文字列
+ */
+#ifndef IUTEST_ASSUME_MATCHES_REGEXEQ
+#  define	IUTEST_ASSUME_MATCHES_REGEXEQ(regex_str, actual)		\
+	IUTEST_TEST_MATCHES_REGEXEQ(regex_str, actual, IUTEST_ASSUME_FAILURE)
+#endif
+
+/**
+ * @ingroup	IUTEST_ASSERT_
+ * @brief	文字列正規表現不一致 テスト
+ * @param	regex_str	= 正規表現文字列
+ * @param	actual		= 検査対象文字列
+*/
+#ifndef IUTEST_ASSERT_MATCHES_REGEXNE
+#  define	IUTEST_ASSERT_MATCHES_REGEXNE(regex_str, actual)		\
+	IUTEST_TEST_MATCHES_REGEXNE(regex_str, actual, IUTEST_ASSERT_FAILURE)
+#endif
+/**
+ * @ingroup	IUTEST_EXPECT_
+ * @brief	文字列正規表現不一致 テスト
+ * @param	regex_str	= 正規表現文字列
+ * @param	actual		= 検査対象文字列
+ */
+#ifndef IUTEST_EXPECT_MATCHES_REGEXNE
+#  define	IUTEST_EXPECT_MATCHES_REGEXNE(regex_str, actual)		\
+	IUTEST_TEST_MATCHES_REGEXNE(regex_str, actual, IUTEST_EXPECT_FAILURE)
+#endif
+/**
+ * @ingroup	IUTEST_INFORM
+ * @brief	文字列正規表現不一致 テスト
+ * @param	regex_str	= 正規表現文字列
+ * @param	actual		= 検査対象文字列
+ */
+#ifndef IUTEST_INFORM_MATCHES_REGEXNE
+#  define	IUTEST_INFORM_MATCHES_REGEXNE(regex_str, actual)		\
+	IUTEST_TEST_MATCHES_REGEXNE(regex_str, actual, IUTEST_INFORM_FAILURE)
+#endif
+/**
+ * @ingroup	IUTEST_ASSUME
+ * @brief	文字列正規表現不一致 テスト
+ * @param	regex_str	= 正規表現文字列
+ * @param	actual		= 検査対象文字列
+ */
+#ifndef IUTEST_ASSUME_MATCHES_REGEXNE
+#  define	IUTEST_ASSUME_MATCHES_REGEXNE(regex_str, actual)		\
+	IUTEST_TEST_MATCHES_REGEXNE(regex_str, actual, IUTEST_ASSUME_FAILURE)
+#endif
+
+
+
+/**
+ * @ingroup	IUTEST_ASSERT_
+ * @brief	文字列正規表現部分一致 テスト
+ * @param	regex_str	= 正規表現文字列
+ * @param	actual		= 検査対象文字列
+*/
+#ifndef IUTEST_ASSERT_CONTAINS_REGEXEQ
+#  define	IUTEST_ASSERT_CONTAINS_REGEXEQ(regex_str, actual)		\
+	IUTEST_TEST_CONTAINS_REGEXEQ(regex_str, actual, IUTEST_ASSERT_FAILURE)
+#endif
+/**
+ * @ingroup	IUTEST_EXPECT_
+ * @brief	文字列正規表現部分一致 テスト
+ * @param	regex_str	= 正規表現文字列
+ * @param	actual		= 検査対象文字列
+ */
+#ifndef IUTEST_EXPECT_CONTAINS_REGEXEQ
+#  define	IUTEST_EXPECT_CONTAINS_REGEXEQ(regex_str, actual)		\
+	IUTEST_TEST_CONTAINS_REGEXEQ(regex_str, actual, IUTEST_EXPECT_FAILURE)
+#endif
+/**
+ * @ingroup	IUTEST_INFORM
+ * @brief	文字列正規表現部分一致 テスト
+ * @param	regex_str	= 正規表現文字列
+ * @param	actual		= 検査対象文字列
+ */
+#ifndef IUTEST_INFORM_CONTAINS_REGEXEQ
+#  define	IUTEST_INFORM_CONTAINS_REGEXEQ(regex_str, actual)		\
+	IUTEST_TEST_CONTAINS_REGEXEQ(regex_str, actual, IUTEST_INFORM_FAILURE)
+#endif
+/**
+ * @ingroup	IUTEST_ASSUME
+ * @brief	文字列正規表現部分一致 テスト
+ * @param	regex_str	= 正規表現文字列
+ * @param	actual		= 検査対象文字列
+ */
+#ifndef IUTEST_ASSUME_CONTAINS_REGEXEQ
+#  define	IUTEST_ASSUME_CONTAINS_REGEXEQ(regex_str, actual)		\
+	IUTEST_TEST_CONTAINS_REGEXEQ(regex_str, actual, IUTEST_ASSUME_FAILURE)
+#endif
+
+/**
+ * @ingroup	IUTEST_ASSERT_
+ * @brief	文字列正規表現部分不一致 テスト
+ * @param	regex_str	= 正規表現文字列
+ * @param	actual		= 検査対象文字列
+*/
+#ifndef IUTEST_ASSERT_CONTAINS_REGEXNE
+#  define	IUTEST_ASSERT_CONTAINS_REGEXNE(regex_str, actual)		\
+	IUTEST_TEST_CONTAINS_REGEXNE(regex_str, actual, IUTEST_ASSERT_FAILURE)
+#endif
+/**
+ * @ingroup	IUTEST_EXPECT_
+ * @brief	文字列正規表現部分不一致 テスト
+ * @param	regex_str	= 正規表現文字列
+ * @param	actual		= 検査対象文字列
+ */
+#ifndef IUTEST_EXPECT_CONTAINS_REGEXNE
+#  define	IUTEST_EXPECT_CONTAINS_REGEXNE(regex_str, actual)		\
+	IUTEST_TEST_CONTAINS_REGEXNE(regex_str, actual, IUTEST_EXPECT_FAILURE)
+#endif
+/**
+ * @ingroup	IUTEST_INFORM
+ * @brief	文字列正規表現部分不一致 テスト
+ * @param	regex_str	= 正規表現文字列
+ * @param	actual		= 検査対象文字列
+ */
+#ifndef IUTEST_INFORM_CONTAINS_REGEXNE
+#  define	IUTEST_INFORM_CONTAINS_REGEXNE(regex_str, actual)		\
+	IUTEST_TEST_CONTAINS_REGEXNE(regex_str, actual, IUTEST_INFORM_FAILURE)
+#endif
+/**
+ * @ingroup	IUTEST_ASSUME
+ * @brief	文字列正規表現部分不一致 テスト
+ * @param	regex_str	= 正規表現文字列
+ * @param	actual		= 検査対象文字列
+ */
+#ifndef IUTEST_ASSUME_CONTAINS_REGEXNE
+#  define	IUTEST_ASSUME_CONTAINS_REGEXNE(regex_str, actual)		\
+	IUTEST_TEST_CONTAINS_REGEXNE(regex_str, actual, IUTEST_ASSUME_FAILURE)
+#endif
+
+#endif
+
 /**
  * @private
  * @brief	for gtest
@@ -245,6 +415,30 @@
 #define ASSUME_STRIN			IUTEST_ASSUME_STRIN
 #define ASSUME_STRNOTIN			IUTEST_ASSUME_STRNOTIN
 
+#if IUTEST_HAS_REGEX
+
+#define ASSERT_MATCHES_REGEXEQ	IUTEST_ASSERT_MATCHES_REGEXEQ
+#define EXPECT_MATCHES_REGEXEQ	IUTEST_EXPECT_MATCHES_REGEXEQ
+#define INFORM_MATCHES_REGEXEQ	IUTEST_INFORM_MATCHES_REGEXEQ
+#define ASSUME_MATCHES_REGEXEQ	IUTEST_ASSUME_MATCHES_REGEXEQ
+
+#define ASSERT_MATCHES_REGEXNE	IUTEST_ASSERT_MATCHES_REGEXNE
+#define EXPECT_MATCHES_REGEXNE	IUTEST_EXPECT_MATCHES_REGEXNE
+#define INFORM_MATCHES_REGEXNE	IUTEST_INFORM_MATCHES_REGEXNE
+#define ASSUME_MATCHES_REGEXNE	IUTEST_ASSUME_MATCHES_REGEXNE
+
+#define ASSERT_CONTAINS_REGEXEQ	IUTEST_ASSERT_CONTAINS_REGEXEQ
+#define EXPECT_CONTAINS_REGEXEQ	IUTEST_EXPECT_CONTAINS_REGEXEQ
+#define INFORM_CONTAINS_REGEXEQ	IUTEST_INFORM_CONTAINS_REGEXEQ
+#define ASSUME_CONTAINS_REGEXEQ	IUTEST_ASSUME_CONTAINS_REGEXEQ
+
+#define ASSERT_CONTAINS_REGEXNE	IUTEST_ASSERT_CONTAINS_REGEXNE
+#define EXPECT_CONTAINS_REGEXNE	IUTEST_EXPECT_CONTAINS_REGEXNE
+#define INFORM_CONTAINS_REGEXNE	IUTEST_INFORM_CONTAINS_REGEXNE
+#define ASSUME_CONTAINS_REGEXNE	IUTEST_ASSUME_CONTAINS_REGEXNE
+
+#endif
+
 /**
  * @}
 */
@@ -260,6 +454,16 @@
 #define IUTEST_TEST_STRIN(substr, actual, on_failure)		IUTEST_PRED_FORMAT2_( ::iuutil::CmpHelperSTRIN, substr, actual, on_failure )
 #define IUTEST_TEST_STRNOTIN(substr, actual, on_failure)	IUTEST_PRED_FORMAT2_( ::iuutil::CmpHelperSTRNOTIN, substr, actual, on_failure )
 
+#if IUTEST_HAS_REGEX
+
+#define IUTEST_TEST_MATCHES_REGEXEQ(regex_str, actual, on_failure) IUTEST_PRED_FORMAT2_( ::iuutil::CmpHelperMatchesRegexEq, regex_str, actual, on_failure )
+#define IUTEST_TEST_MATCHES_REGEXNE(regex_str, actual, on_failure) IUTEST_PRED_FORMAT2_( ::iuutil::CmpHelperMatchesRegexNe, regex_str, actual, on_failure )
+
+#define IUTEST_TEST_CONTAINS_REGEXEQ(regex_str, actual, on_failure) IUTEST_PRED_FORMAT2_( ::iuutil::CmpHelperContainsRegexEq, regex_str, actual, on_failure )
+#define IUTEST_TEST_CONTAINS_REGEXNE(regex_str, actual, on_failure) IUTEST_PRED_FORMAT2_( ::iuutil::CmpHelperContainsRegexNe, regex_str, actual, on_failure )
+
+#endif
+
 /**
  * @}
 */
@@ -545,6 +749,177 @@ inline ::iutest::AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperSTRNOTIN(cons
 	return StrNotInHelper::Assertion(substr_str, actual_str, substr, actual);
 }
 
+#if IUTEST_HAS_REGEX
+
+namespace RegexHelper
+{
+
+inline bool FullMatch(const ::std::string& str, ::iutest::internal::RE& re)
+{
+	return ::iutest::internal::RE::FullMatch(str, re);
+}
+inline bool FullMatch(const char* str, ::iutest::internal::RE& re)
+{
+	if( str == NULL ) return false;
+	return ::iutest::internal::RE::FullMatch(str, re);
+}
+
+inline bool PartialMatch(const ::std::string& str, ::iutest::internal::RE& re)
+{
+	return ::iutest::internal::RE::PartialMatch(str, re);
+}
+inline bool PartialMatch(const char* str, ::iutest::internal::RE& re)
+{
+	if( str == NULL ) return false;
+	return ::iutest::internal::RE::PartialMatch(str, re);
+}
+
+}
+
+namespace MatchesRegexEqHelper
+{
+
+template<typename T1, typename T2>
+inline bool IUTEST_ATTRIBUTE_UNUSED_ Compare(const T1& regex_str, const T2& actual)
+{
+	::iutest::internal::RE m(regex_str);
+	return RegexHelper::FullMatch(actual, m);
+}
+
+template<typename T1, typename T2>
+inline ::iutest::AssertionResult IUTEST_ATTRIBUTE_UNUSED_ Assertion(const char* regex_str, const char* actual_str
+	, const T1& regex, const T2& actual)
+{
+	if( Compare(regex, actual) )
+	{
+		return ::iutest::AssertionSuccess();
+	}
+	::std::string expected_str = "Matches Regex (";
+	expected_str += regex_str;
+	expected_str += ")";
+
+	return ::iutest::internal::EqFailure(expected_str.c_str(), actual_str
+		, ::iutest::PrintToString(regex)
+		, ::iutest::PrintToString(actual)
+		, false);
+}
+
+}
+
+/**
+ * @brief	文字列正規表現一致アサーションフォーマッター
+*/
+inline ::iutest::AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperMatchesRegexEq(const char* regex, const char* actual_str
+	, const char* regex_str, const char* actual)
+{
+	return MatchesRegexEqHelper::Assertion(regex, actual_str, regex_str, actual);
+}
+
+namespace MatchesRegexNeHelper
+{
+
+template<typename T1, typename T2>
+inline ::iutest::AssertionResult IUTEST_ATTRIBUTE_UNUSED_ Assertion(const char* regex_str, const char* actual_str
+	, const T1& regex, const T2& actual)
+{
+	if( !MatchesRegexEqHelper::Compare(regex, actual) )
+	{
+		return ::iutest::AssertionSuccess();
+	}
+	::std::string expected_str = "Not Matches Regex (";
+	expected_str += regex_str;
+	expected_str += ")";
+
+	return ::iutest::internal::EqFailure(expected_str.c_str(), actual_str
+		, ::iutest::PrintToString(regex)
+		, ::iutest::PrintToString(actual)
+		, false);
+}
+
+}
+
+/**
+ * @brief	文字列正規表現不一致アサーションフォーマッター
+*/
+inline ::iutest::AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperMatchesRegexNe(const char* regex, const char* actual_str
+	, const char* regex_str, const char* actual)
+{
+	return MatchesRegexNeHelper::Assertion(regex, actual_str, regex_str, actual);
+}
+
+namespace ContainsRegexEqHelper
+{
+
+template<typename T1, typename T2>
+inline bool IUTEST_ATTRIBUTE_UNUSED_ Compare(const T1& regex_str, const T2& actual)
+{
+	::iutest::internal::RE m(regex_str);
+	return RegexHelper::PartialMatch(actual, m);
+}
+
+template<typename T1, typename T2>
+inline ::iutest::AssertionResult IUTEST_ATTRIBUTE_UNUSED_ Assertion(const char* regex_str, const char* actual_str
+	, const T1& regex, const T2& actual)
+{
+	if( Compare(regex, actual) )
+	{
+		return ::iutest::AssertionSuccess();
+	}
+	::std::string expected_str = "Contains Regex (";
+	expected_str += regex_str;
+	expected_str += ")";
+
+	return ::iutest::internal::EqFailure(expected_str.c_str(), actual_str
+		, ::iutest::PrintToString(regex)
+		, ::iutest::PrintToString(actual)
+		, false);
+}
+
+}
+
+/**
+ * @brief	文字列正規表現部分一致アサーションフォーマッター
+*/
+inline ::iutest::AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperContainsRegexEq(const char* regex, const char* actual_str
+	, const char* regex_str, const char* actual)
+{
+	return ContainsRegexEqHelper::Assertion(regex, actual_str, regex_str, actual);
+}
+
+namespace ContainsRegexNeHelper
+{
+
+template<typename T1, typename T2>
+inline ::iutest::AssertionResult IUTEST_ATTRIBUTE_UNUSED_ Assertion(const char* regex_str, const char* actual_str
+	, const T1& regex, const T2& actual)
+{
+	if( !ContainsRegexEqHelper::Compare(regex, actual) )
+	{
+		return ::iutest::AssertionSuccess();
+	}
+	::std::string expected_str = "Not Contains Regex (";
+	expected_str += regex_str;
+	expected_str += ")";
+
+	return ::iutest::internal::EqFailure(expected_str.c_str(), actual_str
+		, ::iutest::PrintToString(regex)
+		, ::iutest::PrintToString(actual)
+		, false);
+}
+
+}
+
+/**
+ * @brief	文字列正規表現部分不一致アサーションフォーマッター
+*/
+inline ::iutest::AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperContainsRegexNe(const char* regex, const char* actual_str
+	, const char* regex_str, const char* actual)
+{
+	return ContainsRegexNeHelper::Assertion(regex, actual_str, regex_str, actual);
+}
+
+#endif
+
 /**
  * @private
  * @{
