@@ -1,15 +1,13 @@
-//======================================================================
+﻿//======================================================================
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_all_tests.cpp
- * @brief		iutest S test
- *
- * @author		t.sirayanagi
- * @version		1.0
+ * @brief		iutest 全部 test
  *
+ * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 //-----------------------------------------------------------------------
@@ -25,24 +23,21 @@
 #include "iutest_filepath_tests.cpp"
 #include "iutest_fixture_tests.cpp"
 #include "iutest_floatingpoint_tests.cpp"
-#include "iutest_no_fatalfailure_tests.cpp"
+#include "iutest_no_failure_tests.cpp"
+#include "iutest_nullptr_tests.cpp"
 #include "iutest_param_test_tests1.cpp"
 #include "iutest_param_test_tests2.cpp"
-#include "iutest_param_method_tests.cpp"
 #include "iutest_pred_tests.cpp"
-#include "iutest_prod_tests.cpp"
+#include "iutest_prod_tests1.cpp"
+#include "iutest_prod_tests2.cpp"
 #include "iutest_spi_tests.cpp"
 #include "iutest_static_assertion_tests.cpp"
 #include "iutest_string_assertion_tests.cpp"
-#include "iutest_tr1_value_tmp_tests.cpp"
-#include "iutest_package_tests1.cpp"
-#include "iutest_package_tests2.cpp"
-#include "iutest_pp_tests.cpp"
-#include "iutest_pairwise_tests.cpp"
+#include "iutest_syntax_tests.cpp"
+#include "iutest_syntax_gtest_tests.cpp"
 #include "iutest_type_param_tests1.cpp"
 #include "iutest_type_param_tests2.cpp"
 #include "iutest_type_param_tests3.cpp"
 #include "iutest_typed_test_tests.cpp"
-#include "iutest_util_tests.cpp"
-#include "iutest_variadic_templates_tests.cpp"
+#include "iutest_values_tests.cpp"
 
