@@ -2,13 +2,11 @@
 //-----------------------------------------------------------------------
 /**
  * @file		iutest_package_tests1.cpp
- * @brief		iutest package test
- *
- * @author		t.sirayanagi
- * @version		1.0
+ * @brief		package test
  *
+ * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2015, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -17,10 +15,9 @@
 
 //======================================================================
 // include
-#include "../include/iutest.hpp"
 #include "iutest_package_tests.hpp"
 
-namespace pkg1
+IUTEST_PACKAGE(pkg1)
 {
 	IUTEST(Test, A)
 	{
@@ -82,3 +79,15 @@ IUTEST_PACKAGE(pkg2)
 	}
 }
 
+#if IUTEST_HAS_IF_EXISTS
+IUTEST_PACKAGE(pkg2)
+{
+	IUTEST_PACKAGE(pkg3)
+	{
+		IUTEST(Test, A)
+		{
+			IUTEST_EXPECT_PACKAGENAME(pkg2.pkg3, Test);
+		}
+	}
+}
+#endif
